@@ -1,5 +1,5 @@
 package Prometheus::Tiny;
-$Prometheus::Tiny::VERSION = '0.004';
+$Prometheus::Tiny::VERSION = '0.006';
 # ABSTRACT: A tiny Prometheus client
 
 use warnings;
@@ -23,7 +23,12 @@ sub new {
 
 sub _format_labels {
   my ($self, $labels) = @_;
-  join ',', map { qq{$_="$labels->{$_}"} } sort keys %$labels;
+  join ',', map {
+    my $lv = $labels->{$_};
+    $lv =~ s/(["\\])/\\$1/sg;
+    $lv =~ s/\n/\\n/sg;
+    qq{$_="$lv"}
+  } sort keys %$labels;
 }
 
 sub set {
@@ -49,6 +54,12 @@ sub dec {
   return $self->add($name, -1, $labels);
 }
 
+sub clear {
+  my ($self, $name) = @_;
+  $self->{metrics} = {};
+  return;
+}
+
 sub histogram_observe {
   my ($self, $name, $value, $labels) = @_;
 
@@ -204,6 +215,12 @@ A shortcut for
 
     $prom->add($name, -1, { labels })
 
+=head2 clear
+
+    $prom->clear;
+
+Remove all stored metric values. Metric metadata (set by C<declare>) is preserved.
+
 =head2 histogram_observe
 
     $prom->histogram_observe($name, $value, { labels })
@@ -282,6 +299,10 @@ Rob N ★ <robn@robn.io>
 
 ben hengst <ben.hengst@dreamhost.com>
 
+=item *
+
+Danijel Tasov <data@consol.de>
+
 =back
 
 =head1 COPYRIGHT AND LICENSE
